@@ -383,6 +383,10 @@
 #   to display at the function start rather than at its completion. The warning
 #   text was also edited.
 
+# Brianna Hitt - 10.18.2023
+# Added function security to ensure probabilities, Se, and Sp
+#   are all between 0 and 1
+
 operatingCharacteristics2 <-
   function(algorithm, p.vec = NULL, probabilities = NULL, alpha = NULL,
            Se, Sp, hier.config = NULL, rowcol.sz = NULL,
@@ -408,7 +412,7 @@ operatingCharacteristics2 <-
         group.sz <- ncol(hier.config)
         dimnames(hier.config) <- NULL
       }
-    } else if (algorithm %in% c("A2", "IA2", "A2M")) {
+    } else if (algorithm %in% c("A2", "A2M")) {
       if (is.null(rowcol.sz)) {
         stop("Please provide a row/column size for the array testing algorithm.\n")
       } else {
@@ -458,7 +462,10 @@ operatingCharacteristics2 <-
           stop("You have specified an overall joint probability vector for an informative algorithm. Please specify a matrix of joint probabilities for each individual using the 'probabilities' argument, or specify shape parameters for the Dirichlet distribution using the 'alpha' argument.\n")
         }
         if (round(sum(p.vec), 6) != 1.000000) {
-          stop("Please specify joint probabilities that sum to 1.")
+          stop("Please specify joint probabilities that sum to 1.\n")
+        }
+        if (any(p.vec < 0) | any(p.vec > 1)) {
+          stop("Please specify overall joint probabilities between 0 and 1.\n")
         }
       } else if (!is.null(probabilities)) {
         if (length(group.sz) == 1) {
@@ -478,6 +485,15 @@ operatingCharacteristics2 <-
                all.equal(probabilities[4,], rep(probabilities[4,1], dim(probabilities)[2])) != TRUE)) {
             stop("You have specified a heterogeneous matrix of joint probabilities for a non-informative algorithm. Please specify a homogeneous matrix of joint probabilities using the 'probabilities' argument or specify an overall joint probability vector using the 'p.vec' argument.\n")
           }
+
+          if (any(round(colSums(probabilities), 6) != 1.000000)) {
+            stop("Please specify a matrix of joint probabilities where the probabilities for each individual (column) sum to 1.\n")
+          }
+
+          if (any(as.vector(probabilities) < 0) | any(as.vector(probabilities) > 1)) {
+            stop("Please specify joint probabilities between 0 and 1.\n")
+          }
+
         } else {
           stop("You have specified a matrix of joint probabilities along with a range of group sizes. Please specify a single group size.\n")
         }
@@ -491,6 +507,50 @@ operatingCharacteristics2 <-
       }
     }
 
+    if (is.null(dim(Se))) {
+      if (length(Se) != 2) {
+        stop("The sensitivity values are not the correct size. Please specify a matrix of sensitivity values (with rows corresponding to each disease and columns corresponding to each stage of testing), or a vector of sensitivity values corresponding to each disease (assumed to be the same for all stages of testing).\n")
+      }
+
+      if (any(Se < 0) | any(Se > 1)) {
+        stop("Please provide sensitivity values between 0 and 1.\n")
+      }
+    } else {
+      if (dim(Se)[1] != 2 |
+          (algorithm %in% c("D2", "ID2", "A2") & dim(Se)[2] != 2) |
+          (algorithm %in% c("D3", "ID3", "A2M") & dim(Se)[2] != 3) |
+          (algorithm %in% c("D4", "ID4") & dim(Se)[2] != 4) |
+          (algorithm %in% c("D5", "ID5") & dim(Se)[2] != 5)) {
+        stop("The sensitivity values are not the correct size. Please specify a matrix of sensitivity values (with rows corresponding to each disease and columns corresponding to each stage of testing), or a vector of sensitivity values corresponding to each disease (assumed to be the same for all stages of testing).\n")
+      }
+
+      if (dim(Se)[1] == 2 & (any(as.vector(Se) < 0) | any(as.vector(Se) > 1))) {
+        stop("Please provide sensitivity values between 0 and 1.\n")
+      }
+    }
+
+    if (is.null(dim(Sp))) {
+      if (length(Sp) != 2) {
+        stop("The sensitivity values are not the correct size. Please specify a matrix of sensitivity values (with rows corresponding to each disease and columns corresponding to each stage of testing), or a vector of sensitivity values corresponding to each disease (assumed to be the same for all stages of testing).\n")
+      }
+
+      if (any(Sp < 0) | any(Sp > 1)) {
+        stop("Please provide sensitivity values between 0 and 1.\n")
+      }
+    } else {
+      if (dim(Sp)[1] != 2 |
+          (algorithm %in% c("D2", "ID2", "A2") & dim(Sp)[2] != 2) |
+          (algorithm %in% c("D3", "ID3", "A2M") & dim(Sp)[2] != 3) |
+          (algorithm %in% c("D4", "ID4") & dim(Sp)[2] != 4) |
+          (algorithm %in% c("D5", "ID5") & dim(Sp)[2] != 5)) {
+        stop("The sensitivity values are not the correct size. Please specify a matrix of sensitivity values (with rows corresponding to each disease and columns corresponding to each stage of testing), or a vector of sensitivity values corresponding to each disease (assumed to be the same for all stages of testing).\n")
+      }
+
+      if (dim(Sp)[1] == 2 & (any(as.vector(Sp) < 0) | any(as.vector(Sp) > 1))) {
+        stop("Please provide sensitivity values between 0 and 1.\n")
+      }
+    }
+
     Se <- generate.acc(algorithm = algorithm, diseases = 2, value = Se,
                        label = "sens")
     Sp <- generate.acc(algorithm = algorithm, diseases = 2, value = Sp,
@@ -534,9 +594,31 @@ operatingCharacteristics2 <-
       }
     }
 
-    if (is.null(a)) {
-      if (algorithm %in% c("D2", "D3", "D4", "D5",
-                           "ID2", "ID3", "ID4", "ID5")) {
+    if (!is.null(a)) {
+      if (algorithm %in% c("D2", "D3", "D4", "ID2", "ID3", "ID4")) {
+        if (length(a) == 1) {
+          if (a > group.sz) {
+            stop("Please specify values for 'a' between 1 and the number of individuals being tested.\n")
+          }
+        } else if (length(a) > 1) {
+          if (any(a > group.sz)) {
+            stop("Please specify values for 'a' between 1 and the number of individuals being tested.\n")
+          }
+        }
+      } else if (algorithm %in% c("A2", "IA2", "A2M")) {
+        if (length(a) == 1) {
+          if (a > group.sz^2) {
+            stop("Please specify values for 'a' between 1 and the number of individuals being tested.\n")
+          }
+        } else if (length(a) > 1) {
+          if (any(a > group.sz^2)) {
+            stop("Please specify values for 'a' between 1 and the number of individuals being tested.\n")
+          }
+        }
+      }
+
+    } else {
+      if (algorithm %in% c("D2", "D3", "D4", "ID2", "ID3", "ID4")) {
         a <- 1:group.sz
       } else if (algorithm %in% c("A2", "A2M", "IA2")) {
         a <- 1:group.sz^2
